linchpin.cli module
===================

This page contains the list of project's modules

.. automodule:: linchpin.cli

.. autoclass:: LinchpinCli

  .. automethod:: __init__
  .. automethod:: lp_up
  .. automethod:: lp_destroy
  .. automethod:: lp_down
  .. automethod:: run_playbook
  .. automethod:: find_topology
  .. automethod:: get_cfg
  .. automethod:: set_cfg
  .. automethod:: get_evar
  .. automethod:: set_evar
  .. automethod:: set_magic_var

  .. -- deprecated methods --

  .. automethod:: lp_rise
  .. automethod:: lp_drop

.. automodule:: linchpin.cli.context
    :members:
    :undoc-members:
    :inherited-members:
